repRows <- function(data, col_split, sep, new_col_name, debug=FALSE) {
    ## repeat rows where there is more than one item in a comma separated character string (the col_split column)
    ## (so that rows will be double-counted when graphing/tabulating)

    ## make the column a character if needed (e.g. if it was a factor, say)
    data[[col_split]] <- as.character(data[[col_split]])
    
    ## use strsplit to get the items in that column - as a list (one element per row)
    spl <- strsplit(data[[col_split]],sep)

    ## work out how many times to replicate each row
    reps <- sapply(spl,length)

    ## an ID to uniquely number each row of the data (1,2,3, etc.)
    data$id <- seq(nrow(data))

    ## replicate the rows and append the items from the strsplit above as a new column 
    out <- data[rep(data$id,reps),]
    out[[new_col_name]] <- unlist(spl)
    
    ## output - append the individual items to the expanded data frame
    ## return the other pieces in case we want to check/debug (if debug flag is on)
    if(debug) return(out=out, spl=spl, reps=reps)
    ## else just return the expanded data frame 
    else out
}
